@@ -7,7 +7,7 @@ use Mu;
 use strictures 2;
 use namespace::clean;
 
-our $VERSION = '0.003000';
+our $VERSION = '0.003001';
 $VERSION =~ tr/_//d;
 
 sub import {
@@ -17,7 +17,7 @@ sub import {
   my $targ = caller;
   my $cb = $class->new($opts||{})->dump_cb;
   no strict 'refs';
-  *{"${targ}::ddc"} = $cb;
+  *{"${targ}::${ddc}"} = $cb;
 }
 
 ro max_width => default => 78;
